import java.text.*;		// for Date and GregorianCalendar
import java.util.*;		// for SimpleDateFormat and Locale

/**
 * Class used to convert 1 data type to another, when no
 * predefined conversion method exists.
 *
 * @version 	1.0, 25/02/98
 * @author 	Wendy Gasperazzo, Real Gagnon
 */
public class TypeConverter
{

	/**
	 * Converts a formatted String to a Date. The format is defaulted to "dd-MMM-yyyy HH:mm:ss"
	 * and the Locale to "Locale.US".
	 *
	 * @param 	as_inString : the String to be converted.
	 */
	public static Date stringToDate (String as_inString) throws DateConversionException
	{
		return stringToDate (as_inString, "dd-MMM-yyyy HH:mm:ss", Locale.US);
	}

	/**
	 * Converts a formatted String to a Date, using the specified format. The Locale is defaulted
	 * to "Locale.US".
	 *
	 * @param 	as_inString : the String to be converted.
	 * @param	as_dateFormat : the String representing the date format.
	 */
	public static Date stringToDate (String as_inString, String as_dateFormat) throws DateConversionException
	{
		return stringToDate (as_inString, as_dateFormat, Locale.US);
	}

	/**
	 * Converts a formatted String to a Date, using the specified format and Locale.
	 *
	 * @param 	as_inString : the String to be converted.
	 * @param	as_dateFormat : the String representing the date format.
	 * @param	a_locale : the Locale to be used ("Locale.US" if the month names are in English, ...).
	 */
	public static Date stringToDate (String as_inString, String as_dateFormat, Locale a_locale) throws DateConversionException
	{
		Date d;
		
		try 
		{
			/*
			** we specify the date format to use in parsing and the Locale.
			*/
			SimpleDateFormat sdf = new SimpleDateFormat (as_dateFormat, a_locale);

			/* 
			** fix timezone in the SimpleDateFormat
			** bug in JDK1.1
			*/
			sdf.setCalendar (Calendar.getInstance());

			/*
			** create a Date (parse returns a Date object)
			*/
			d = sdf.parse(as_inString);
		}	// try
		catch (Exception e)
		{
			e.printStackTrace();
			throw (new DateConversionException ("Failed to convert " +  as_inString + 
									" (" + e.getMessage () + ")"));
		}
		
		return d;
	}
	
	public static GregorianCalendar stringToGregorianCalendar (String as_inString, String as_dateFormat, Locale a_locale) throws DateConversionException
	{
		GregorianCalendar gc;
		
		try 
		{
			Date d = stringToDate (as_inString, as_dateFormat, a_locale);

			/*
			** create a GregorianCalendar from a Date object
			*/
			gc = new GregorianCalendar();
			gc.setTime(d);
			
		}	// try
		catch (DateConversionException e)
		{
			throw e;
		}
		
		return gc;
	}

}